package com.lantone.qc.kernel.catalogue.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.entity.Allergy;
import com.lantone.qc.pub.model.label.PastLabel;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @Description: 药物过敏史未填写
 * @author: rengb
 * @time: 2020/3/10 14:02
 */
@Component
public class BEH0027 extends QCCatalogue {

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if (inputInfo.getBeHospitalizedDoc() == null) {
            status.set("0");
            return;
        }
        PastLabel pastLabel = inputInfo.getBeHospitalizedDoc().getPastLabel();
        if (pastLabel == null) {
            status.set("0");
            return;
        }
        String pastText = pastLabel.getText();
        if (StringUtil.isNotBlank(pastText) && pastText.contains("药物过敏史")) {
            status.set("0");
            return;
        }
        List<Allergy> allergies = pastLabel.getAllergies();
        if (ListUtil.isNotEmpty(allergies)) {
            long count = allergies.stream().filter(
                    i -> i != null
                            && StringUtil.isNotBlank(i.getName())
                            && i.getAllergyMedicine() != null
                            && StringUtil.isNotBlank(i.getAllergyMedicine().getName())
            ).count();
            if (count > 0) {
                status.set("0");
            }
        }
    }

}