package com.lantone.qc.kernel.catalogue.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.entity.Allergy;
import com.lantone.qc.pub.model.label.PastLabel;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.stream.Collectors;

/**
 * @Description: 过敏药物未标引号
 * @author: rengb
 * @time: 2020/3/10 14:02
 */
@Component
public class BEH0035 extends QCCatalogue {

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        if(inputInfo.getBeHospitalizedDoc() == null){
            return;
        }
        PastLabel pastLabel = inputInfo.getBeHospitalizedDoc().getPastLabel();
        List<Allergy> allergies = pastLabel.getAllergies();
        if (ListUtil.isEmpty(allergies)) {
            return;
        }

        List<String> wtAmNames = CatalogueUtil.noInQuotes(
                allergies.stream().filter(
                        i -> i != null && StringUtil.isNotBlank(i.getName()) && i.getNegative() == null
                                && i.getAllergyMedicine() != null && StringUtil.isNotBlank(i.getAllergyMedicine().getName()))
                        .map(i -> i.getAllergyMedicine().getName()).distinct().collect(Collectors.toList()),
                pastLabel.getText()
        );
        if(wtAmNames.contains("止痛片")){
            return;
        }
        if (ListUtil.isNotEmpty(wtAmNames)) {
            status.set("-1");
            for (String wtAmName : wtAmNames) {
                info.set(info.get() + wtAmName + " ");
            }
        }
    }

}