package com.lantone.qc.kernel.catalogue.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.entity.Contact;
import com.lantone.qc.pub.model.label.PersonalLabel;
import com.lantone.qc.pub.util.StringUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * @Description: 放射物、毒物、粉尘接触史未描述
 * @author: rengb
 * @time: 2020/3/10 14:02
 */
@Component
public class BEH0048 extends QCCatalogue {

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if (inputInfo.getBeHospitalizedDoc() == null) {
            status.set("0");
            return;
        }
        Map<String, String> structureMap = inputInfo.getBeHospitalizedDoc().getStructureMap();
        if (StringUtils.isNotEmpty(structureMap.get("化学及放射性毒物接触史"))) {
            status.set("0");
            return;
        }

        PersonalLabel personalLabel = inputInfo.getBeHospitalizedDoc().getPersonalLabel();
        if (personalLabel == null || StringUtil.isBlank(personalLabel.getText())) {
            status.set("0");
            return;
        }
        String personalText = personalLabel.getText();
        if (personalText.contains("详见原病历")) {
            status.set("0");
            return;
        }
        Contact contact = personalLabel.getContact();
        if (contact != null && StringUtil.isNotBlank(contact.getName())) {
            status.set("0");
        }
    }

}