package com.lantone.qc.trans.beilun;

import com.google.common.collect.Lists;
import com.lantone.qc.pub.model.doc.CriticallyIllNoticeDoc;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.beilun.util.BeiLunCriticallyIllNoticeHtmlAnalysis;
import com.lantone.qc.trans.beilun.util.BeiLunHtmlAnalysis;
import com.lantone.qc.trans.beilun.util.CommonAnalysisUtil;
import com.lantone.qc.trans.comsis.ModelDocGenerate;
import com.lantone.qc.trans.comsis.OrdinaryAssistant;

import java.util.List;
import java.util.Map;

/**
 * @Description: 病危通知书文档生成
 * @author: rengb
 * @time: 2020/3/19 19:41
 */
public class BeiLunCriticallyIllNoticeDocTrans extends ModelDocTrans {

    @Override
    public List<CriticallyIllNoticeDoc> extract(MedrecVo medrecVo) {
        List<CriticallyIllNoticeDoc> retList = Lists.newArrayList();
        List<Map<String, Object>> contentMaps = (List) medrecVo.getContent().get("content");
        contentMaps.forEach(contentMap -> {
            retList.add(getCriticallyIllNoticeDoc(contentMap));
        });
        return retList;
    }

    private CriticallyIllNoticeDoc getCriticallyIllNoticeDoc(Map<String, Object> contentMap) {
        String content = contentMap.get("xmlText").toString();
        String recTitle = contentMap.get("recTitle").toString();
        String recTypeId = contentMap.get("recTypeId").toString();
        BeiLunHtmlAnalysis beiLunHtmlAnalysis = new BeiLunCriticallyIllNoticeHtmlAnalysis();
        Map<String, String> sourceMap = beiLunHtmlAnalysis.analysis(content, recTitle, recTypeId);
        Map<String, String> structureMap = OrdinaryAssistant.mapKeyContrast(sourceMap, keyContrasts);

        String text = CommonAnalysisUtil.html2String(content);
        CriticallyIllNoticeDoc criticallyIllNoticeDoc = ModelDocGenerate.criticallyIllNoticeDocGen(structureMap);
        criticallyIllNoticeDoc.setText(text);
        criticallyIllNoticeDoc.setPageData((Map) structureMap);

        return criticallyIllNoticeDoc;
    }

    private List<String> sourceTitles = Lists.newArrayList(
            "记录时间",
            "记录医师",
            "姓名",
            "性别",
            "病区",
            "床号",
            "病案号",
            "目前诊断",
            "签名",
            "签名时间"
    );

    private List<String> keyContrasts = Lists.newArrayList(
            "姓名++++患者姓名=姓名",
            "性别=",
            "病区++++病区名称=病区",
            "床号=",
            "病案号++++住院号=病案号",
            "目前诊断++++初步诊断=目前诊断",
            "签名++++=签名",
            "签名时间="
    );

}