package com.lantone.qc.trans.beilun;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.lantone.qc.pub.model.doc.FirstCourseRecordDoc;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.beilun.util.BeiLunFirstCourseRecordHtmlAnalysis;
import com.lantone.qc.trans.beilun.util.CommonAnalysisUtil;
import com.lantone.qc.trans.comsis.ModelDocGenerate;
import com.lantone.qc.trans.comsis.OrdinaryAssistant;
import com.lantone.qc.trans.comsis.Preproc;

import java.util.List;
import java.util.Map;

import static com.lantone.qc.trans.comsis.ModelDocGenerate.structureMapJoin;

/**
 * @Description: 首次病程录文档生成
 * @author: rengb
 * @time: 2020/3/17 13:25
 */
public class BeiLunFirstCourseRecordDocTrans extends ModelDocTrans {

    @Override
    public FirstCourseRecordDoc extract(MedrecVo medrecVo) {
        Map<String, Object> contentMap = ((List<Map>) medrecVo.getContent().get("content")).get(0);
        String content = contentMap.get("xmlText").toString();
        String recTitle = contentMap.get("recTitle").toString();
        String recTypeId = contentMap.get("recTypeId").toString();
        BeiLunFirstCourseRecordHtmlAnalysis beiLunFirstCourseRecordHtmlAnalysis = new BeiLunFirstCourseRecordHtmlAnalysis();
        Map<String, String> sourceMap = beiLunFirstCourseRecordHtmlAnalysis.analysis(content, recTitle, recTypeId);
        //Map<String, String> xmlNodeValueMap = CxXmlUtil.firstLevelNodeValue(content);
        sourceMap = removeSerialNumber(sourceMap);
        Map<String, String> structureMap = OrdinaryAssistant.mapKeyContrast(sourceMap, keyContrasts);
        String text = CommonAnalysisUtil.html2String(content);
        //Map<String, String> cutWordMap = getCutWordMap(text);
        //cutWordMap.putAll(structureMap);
        FirstCourseRecordDoc firstCourseRecordDoc = ModelDocGenerate.firstCourseRecordDocGen(structureMap);
        firstCourseRecordDoc.setText(text);
        firstCourseRecordDoc.setPageData((Map) structureMap);
        List<String> keys = Lists.newArrayList("需求评估", "预期目标", "诊疗计划", "治疗监测计划");
        String treatPlanJoin = structureMapJoin(structureMap, keys);
        firstCourseRecordDoc.getTreatPlanLabel().setAiText(treatPlanJoin);
        return firstCourseRecordDoc;
    }

    private Map<String, String> removeSerialNumber(Map<String, String> sourceMap) {
        Map<String, String> structureMap = Maps.newLinkedHashMap();
        sourceMap.forEach((key, value) -> structureMap.put(key.replaceAll("[一二三四五六()（）.123456]", ""), value));
        return structureMap;
    }

    private Map<String, String> getCutWordMap(String content) {
        Map<String, String> retMap = Maps.newHashMap();
        if (StringUtil.isBlank(content)) {
            return retMap;
        }
        List<String> targetTitles = Lists.newArrayList();
        sourceTitles.forEach(sourceTitle -> {
            String targetTitle = "[一二三四五六七八九十]{0,1}[、.]{0,1}";
            for (int index = 0; index < sourceTitle.length(); index++) {
                if (index == sourceTitle.length() - 1) {
                    targetTitle += sourceTitle.substring(index, index + 1);
                } else {
                    targetTitle += sourceTitle.substring(index, index + 1) + "[\\s\\p{Zs}]*";
                }
            }
            targetTitles.add(targetTitle);
        });
        Map<String, String> sourceMap = Preproc.extract_doc_pub(true, targetTitles, content);
        for (String key : sourceMap.keySet()) {
            retMap.put(key.replaceAll("[一二三四五六七八九十、.]", ""), sourceMap.get(key));
        }
        return retMap;
    }

    private List<String> sourceTitles = Lists.newArrayList(
            "病例特点",
            "初步诊断",
            "诊断依据",
            "鉴别诊断",
            "诊疗计划"
    );

    private List<String> keyContrasts = Lists.newArrayList(
            "时间=病历日期",
            "病历特点=病例特点",
            "入院查体=查体",
            "辅助检查=辅检"
    );

}