package com.lantone.qc.trans.changx;

import com.google.common.collect.Lists;
import com.lantone.qc.pub.model.doc.StagesSummaryDoc;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.dbanaly.facade.changx.CxXmlUtil;
import com.lantone.qc.trans.comsis.ModelDocGenerate;
import com.lantone.qc.trans.comsis.OrdinaryAssistant;
import com.lantone.qc.trans.comsis.Preproc;

import java.util.List;
import java.util.Map;

/**
 * @Description: 阶段小结文档生成
 * @author: rengb
 * @time: 2020/3/19 19:41
 */
public class ChangxStagesSummaryDocTrans extends ModelDocTrans {

    @Override
    public List<StagesSummaryDoc> extract(MedrecVo medrecVo) {
        List<StagesSummaryDoc> retList = Lists.newArrayList();
        List<Map<String, Object>> contentMaps = (List) medrecVo.getContent().get("content");
        contentMaps.forEach(contentMap -> {
            retList.add(getStagesSummaryDoc(contentMap));
        });
        return retList;
    }

    private StagesSummaryDoc getStagesSummaryDoc(Map<String, Object> contentMap) {
        String content = contentMap.get("xmlText").toString();
        Map<String, String> xmlNodeValueMap = CxXmlUtil.firstLevelNodeValue(content);
        xmlNodeValueMap.put("mode_id=" + contentMap.get("modeId").toString(), "");
        xmlNodeValueMap.put("rec_title=" + contentMap.get("recTitle").toString(), "");
        Map<String, String> structureMap = OrdinaryAssistant.mapKeyContrast(xmlNodeValueMap, keyContrasts);

        String text = CxXmlUtil.getXmlText(content);
        Map<String, String> cutWordMap = Preproc.getCutWordMap(true, sourceTitles, text);
        cutWordMap.putAll(structureMap);

        StagesSummaryDoc stagesSummaryDoc = ModelDocGenerate.stagesSummaryDocGen(cutWordMap);
        stagesSummaryDoc.setText(text);
        stagesSummaryDoc.setPageData((Map) cutWordMap);

        return stagesSummaryDoc;
    }

    private List<String> sourceTitles = Lists.newArrayList(
            "记录日期",
            "患者姓名（住院）",
            "性别",
            "年龄",
            "原因",
            "入院日期",
            "入院情况",
            "入院诊断",
            "治疗经过",
            "目前情况",
            "目前诊断",
            "诊疗计划",
            "签名",
            "签名时间"
    );

    private List<String> keyContrasts = Lists.newArrayList(
            "记录日期=",
            "患者姓名（住院）=",
            "主管护士++++责任护士=护理",
            "其他住院医师++++其他人员=其他人员",
            "性别=",
            "年龄=",
            "原因=",
            "入院日期=",
            "入院情况=",
            "入院诊断++++初步诊断=入院诊断",
            "治疗经过=",
            "目前情况=",
            "目前诊断=",
            "诊疗计划++++下一步诊疗计划=诊疗计划",
            "签名++++=签名",
            "签名时间="
    );

}